'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskElements = require('lisk-elements');

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _mnemonic = require('../../utils/mnemonic');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const createAccount = () => {
	const passphrase = (0, _mnemonic.createMnemonicPassphrase)();
	const { privateKey, publicKey } = _liskElements.cryptography.getKeys(passphrase);
	const address = _liskElements.cryptography.getAddressFromPublicKey(publicKey);
	return {
		passphrase,
		privateKey,
		publicKey,
		address
	};
};

class CreateCommand extends _base2.default {
	async run() {
		const { flags: { number: numberStr } } = this.parse(CreateCommand);
		const number = parseInt(numberStr, 10);
		if (numberStr !== number.toString() || !Number.isInteger(number) || number <= 0) {
			throw new Error('Number flag must be an integer and greater than 0');
		}
		const accounts = new Array(number).fill().map(createAccount);
		this.print(accounts);
	}
}

exports.default = CreateCommand;
CreateCommand.flags = Object.assign({}, _base2.default.flags, {
	number: _command.flags.string({
		char: 'n',
		description: 'Number of accounts to create.',
		default: '1'
	})
});

CreateCommand.description = `
Returns a randomly-generated mnemonic passphrase with its corresponding public/private key pair and Lisk address.
`;
CreateCommand.examples = ['account:create', 'account:create --number=3'];