'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskElements = require('lisk-elements');

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _error = require('../../utils/error');

var _input = require('../../utils/input');

var _input2 = _interopRequireDefault(_input);

var _flags = require('../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const processInputs = (recipientPublicKey, message) => ({
	passphrase,
	data
}) => Object.assign({}, _liskElements.cryptography.encryptMessageWithPassphrase(message || data, passphrase, recipientPublicKey), {
	recipientPublicKey
});

class EncryptCommand extends _base2.default {
	async run() {
		const {
			args: { recipientPublicKey, message },
			flags: { passphrase: passphraseSource, message: messageSource }
		} = this.parse(EncryptCommand);

		if (!message && !messageSource) {
			throw new _error.ValidationError('No message was provided.');
		}

		const inputs = await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			},
			data: message ? null : {
				source: messageSource
			}
		});
		const result = processInputs(recipientPublicKey, message)(inputs);
		this.print(result);
	}
}

exports.default = EncryptCommand;
EncryptCommand.args = [{
	name: 'recipientPublicKey',
	description: 'Public key of the recipient of the message.',
	required: true
}, {
	name: 'message',
	description: 'Message to encrypt.'
}];

EncryptCommand.flags = Object.assign({}, _base2.default.flags, {
	passphrase: _command.flags.string(_flags2.default.passphrase),
	message: _command.flags.string(_flags2.default.message)
});

EncryptCommand.description = `
Encrypts a message for a given recipient public key using your secret passphrase.
`;

EncryptCommand.examples = ['message:encrypt bba7e2e6a4639c431b68e31115a71ffefcb4e025a4d1656405dfdcd8384719e0 "Hello world"'];