'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskElements = require('lisk-elements');

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _error = require('../../utils/error');

var _input = require('../../utils/input');

var _input2 = _interopRequireDefault(_input);

var _flags = require('../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const processInputs = message => ({ passphrase, data }) => _liskElements.cryptography.signMessageWithPassphrase(message || data, passphrase);

class SignCommand extends _base2.default {
	async run() {
		const {
			args: { message },
			flags: { passphrase: passphraseSource, message: messageSource }
		} = this.parse(SignCommand);

		if (!message && !messageSource) {
			throw new _error.ValidationError('No message was provided.');
		}

		const inputs = await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			},
			data: message ? null : {
				source: messageSource
			}
		});
		const result = processInputs(message)(inputs);
		this.print(result);
	}
}

exports.default = SignCommand;
SignCommand.args = [{
	name: 'message',
	description: 'Message to sign.'
}];

SignCommand.flags = Object.assign({}, _base2.default.flags, {
	passphrase: _command.flags.string(_flags2.default.passphrase),
	message: _command.flags.string(_flags2.default.message)
});

SignCommand.description = `
Signs a message using your secret passphrase.
`;

SignCommand.examples = ['message:sign "Hello world"'];