'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskElements = require('lisk-elements');

var _liskElements2 = _interopRequireDefault(_liskElements);

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _flags = require('../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

var _api = require('../../utils/api');

var _api2 = _interopRequireDefault(_api);

var _input = require('../../utils/input');

var _input2 = _interopRequireDefault(_input);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const STATUS_ENABLE = 'enable';
const STATUS_DISABLE = 'disable';

const processInput = (client, status, publicKey, password) => client.node.updateForgingStatus({
	password,
	publicKey,
	forging: status === STATUS_ENABLE
}).then(response => response.data);

class ForgingCommand extends _base2.default {
	async run() {
		const {
			args: { status, publicKey },
			flags: { password: passwordSource }
		} = this.parse(ForgingCommand);

		_liskElements2.default.transaction.utils.validatePublicKey(publicKey);

		const client = (0, _api2.default)(this.userConfig.api);
		const { password } = await (0, _input2.default)({
			password: {
				source: passwordSource
			}
		});
		const result = await processInput(client, status, publicKey, password);

		this.print(result);
	}
}

exports.default = ForgingCommand;
ForgingCommand.args = [{
	name: 'status',
	options: [STATUS_ENABLE, STATUS_DISABLE],
	description: 'Desired forging status.',
	required: true
}, {
	name: 'publicKey',
	description: 'Public key of the delegate whose status should be updated.',
	required: true
}];

ForgingCommand.flags = Object.assign({}, _base2.default.flags, {
	password: _command.flags.string(_flags2.default.password)
});

ForgingCommand.description = `
Updates the forging status of a node.
`;

ForgingCommand.examples = ['node:forging enable 647aac1e2df8a5c870499d7ddc82236b1e10936977537a3844a6b05ea33f9ef6', 'node:forging disable 647aac1e2df8a5c870499d7ddc82236b1e10936977537a3844a6b05ea33f9ef6'];