'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _error = require('../../utils/error');

var _utils = require('../../utils/input/utils');

var _api = require('../../utils/api');

var _api2 = _interopRequireDefault(_api);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const getSignatureInput = async () => {
	try {
		const { data } = await (0, _utils.getStdIn)({ dataIsRequired: true });
		if (!data) {
			throw new _error.ValidationError('No signature was provided.');
		}
		return data;
	} catch (e) {
		throw new _error.ValidationError('No signature was provided.');
	}
};

class BroadcastCommand extends _base2.default {
	async run() {
		const { args: { signature } } = this.parse(BroadcastCommand);
		const signatureInput = signature || (await getSignatureInput());
		let signatureObject;
		try {
			signatureObject = JSON.parse(signatureInput);
		} catch (error) {
			throw new _error.ValidationError('Could not parse signature JSON. Did you use the `--json` option?');
		}
		const client = (0, _api2.default)(this.userConfig.api);
		const response = await client.signatures.broadcast(signatureObject);
		this.print(response.data);
	}
}

exports.default = BroadcastCommand;
BroadcastCommand.args = [{
	name: 'signature',
	description: 'Signature to broadcast.'
}];

BroadcastCommand.flags = Object.assign({}, _base2.default.flags);

BroadcastCommand.description = `
Broadcasts a signature for a transaction from a multisignature account.
Accepts a stringified JSON signature as an argument, or a signature can be piped from a previous command.
If piping make sure to quote out the entire command chain to avoid piping-related conflicts in your shell.
`;

BroadcastCommand.examples = ['signature:broadcast \'{"transactionId":"abcd1234","publicKey":"abcd1234","signature":"abcd1234"}\'', 'echo \'{"transactionId":"abcd1234","publicKey":"abcd1234","signature":"abcd1234"}\' | lisk signature:broadcast'];