'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _liskElements = require('lisk-elements');

var _liskElements2 = _interopRequireDefault(_liskElements);

var _command = require('@oclif/command');

var _base = require('../../base');

var _base2 = _interopRequireDefault(_base);

var _utils = require('../../utils/input/utils');

var _error = require('../../utils/error');

var _transactions = require('../../utils/transactions');

var _transactions2 = _interopRequireDefault(_transactions);

var _input = require('../../utils/input');

var _input2 = _interopRequireDefault(_input);

var _flags = require('../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * LiskHQ/lisk-commander
 * Copyright © 2017–2018 Lisk Foundation
 *
 * See the LICENSE file at the top-level directory of this distribution
 * for licensing information.
 *
 * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
 * no part of this software, including this file, may be copied, modified,
 * propagated, or distributed except according to the terms contained in the
 * LICENSE file.
 *
 * Removal or modification of this copyright notice is prohibited.
 *
 */
const getTransactionInput = async () => {
	try {
		const { data } = await (0, _utils.getStdIn)({ dataIsRequired: true });
		if (!data) {
			throw new _error.ValidationError('No transaction was provided.');
		}
		return data;
	} catch (e) {
		throw new _error.ValidationError('No transaction was provided.');
	}
};

class CreateCommand extends _base2.default {
	async run() {
		const {
			args: { transaction },
			flags: { passphrase: passphraseSource }
		} = this.parse(CreateCommand);

		const transactionInput = transaction || (await getTransactionInput());

		const transactionObject = (0, _transactions2.default)(transactionInput);

		const { passphrase } = await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			}
		});

		const result = _liskElements2.default.transaction.createSignatureObject(transactionObject, passphrase);

		this.print(result);
	}
}

exports.default = CreateCommand;
CreateCommand.args = [{
	name: 'transaction',
	description: 'Transaction in JSON format.'
}];

CreateCommand.flags = Object.assign({}, _base2.default.flags, {
	passphrase: _command.flags.string(_flags2.default.passphrase)
});

CreateCommand.description = `
Create a signature object for a transaction from a multisignature account.
Accepts a stringified JSON transaction as an argument.
`;

CreateCommand.examples = ['signature:create \'{"amount":"10","recipientId":"8050281191221330746L","senderPublicKey":"3358a1562f9babd523a768e700bb12ad58f230f84031055802dc0ea58cef1e1b","timestamp":59353522,"type":0,"asset":{},"signature":"b84b95087c381ad25b5701096e2d9366ffd04037dcc941cd0747bfb0cf93111834a6c662f149018be4587e6fc4c9f5ba47aa5bbbd3dd836988f153aa8258e604"}\''];