'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _command = require('@oclif/command');

var _liskElements = require('lisk-elements');

var _liskElements2 = _interopRequireDefault(_liskElements);

var _base = require('../../../base');

var _base2 = _interopRequireDefault(_base);

var _flags = require('../../../utils/flags');

var _flags2 = _interopRequireDefault(_flags);

var _input = require('../../../utils/input');

var _input2 = _interopRequireDefault(_input);

var _utils = require('../../../utils/input/utils');

var _error = require('../../../utils/error');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const processInputs = (votes, unvotes) => ({ passphrase, secondPassphrase }) => _liskElements2.default.transaction.castVotes({
	passphrase,
	votes,
	unvotes,
	secondPassphrase
}); /*
     * LiskHQ/lisk-commander
     * Copyright © 2017–2018 Lisk Foundation
     *
     * See the LICENSE file at the top-level directory of this distribution
     * for licensing information.
     *
     * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
     * no part of this software, including this file, may be copied, modified,
     * propagated, or distributed except according to the terms contained in the
     * LICENSE file.
     *
     * Removal or modification of this copyright notice is prohibited.
     *
     */


const processVotesInput = async votes => votes.includes(':') ? (0, _utils.getData)(votes) : votes;

const processVotes = votes => votes.replace(/\n/g, ',').split(',').filter(Boolean).map(vote => vote.trim());

const validatePublicKeys = inputs => {
	_liskElements2.default.transaction.utils.validatePublicKeys(inputs);
	return inputs;
};

class VoteCommand extends _base2.default {
	async run() {
		const {
			flags: {
				passphrase: passphraseSource,
				'second-passphrase': secondPassphraseSource,
				'no-signature': noSignature,
				votes,
				unvotes
			}
		} = this.parse(VoteCommand);

		if (!votes && !unvotes) {
			throw new _error.ValidationError('At least one of votes and/or unvotes options must be provided.');
		}

		if (votes === unvotes) {
			throw new _error.ValidationError('Votes and unvotes sources must not be the same.');
		}

		const processedVotesInput = votes ? await processVotesInput(votes.toString()) : null;
		const processedUnvotesInput = unvotes ? await processVotesInput(unvotes.toString()) : null;

		const validatedVotes = processedVotesInput ? validatePublicKeys(processVotes(processedVotesInput)) : [];
		const validatedUnvotes = processedUnvotesInput ? validatePublicKeys(processVotes(processedUnvotesInput)) : [];

		const processFunction = processInputs(validatedVotes, validatedUnvotes);

		if (noSignature) {
			const result = processFunction({
				passphrase: null,
				secondPassphrase: null
			});
			return this.print(result);
		}

		const inputs = await (0, _input2.default)({
			passphrase: {
				source: passphraseSource,
				repeatPrompt: true
			},
			secondPassphrase: !secondPassphraseSource ? null : {
				source: secondPassphraseSource,
				repeatPrompt: true
			}
		});

		const result = processFunction(inputs);
		return this.print(result);
	}
}

exports.default = VoteCommand;
VoteCommand.flags = Object.assign({}, _base2.default.flags, {
	passphrase: _command.flags.string(_flags2.default.passphrase),
	'second-passphrase': _command.flags.string(_flags2.default.secondPassphrase),
	'no-signature': _command.flags.boolean(_flags2.default.noSignature),
	votes: _command.flags.string(_flags2.default.votes),
	unvotes: _command.flags.string(_flags2.default.unvotes)
});

VoteCommand.description = `
Creates a transaction which will cast votes (or unvotes) for delegate candidates using their public keys if broadcast to the network.
`;

VoteCommand.examples = ['transaction:create:vote --votes 215b667a32a5cd51a94c9c2046c11fffb08c65748febec099451e3b164452bca,922fbfdd596fa78269bbcadc67ec2a1cc15fc929a19c462169568d7a3df1a1aa --unvotes e01b6b8a9b808ec3f67a638a2d3fa0fe1a9439b91dbdde92e2839c3327bd4589,ac09bc40c889f688f9158cca1fcfcdf6320f501242e0f7088d52a5077084ccba'];