'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});
exports.verifyMessage = exports.signMessage = exports.getAddressFromPublicKey = exports.getKeys = exports.decryptPassphrase = exports.encryptPassphrase = exports.decryptMessage = exports.encryptMessage = undefined;

var _liskElements = require('lisk-elements');

const encryptMessage = exports.encryptMessage = ({ message, passphrase, recipient }) => _liskElements.cryptography.encryptMessageWithPassphrase(message, passphrase, recipient); /*
                                                                                                                                                                                  * LiskHQ/lisk-commander
                                                                                                                                                                                  * Copyright © 2017–2018 Lisk Foundation
                                                                                                                                                                                  *
                                                                                                                                                                                  * See the LICENSE file at the top-level directory of this distribution
                                                                                                                                                                                  * for licensing information.
                                                                                                                                                                                  *
                                                                                                                                                                                  * Unless otherwise agreed in a custom licensing agreement with the Lisk Foundation,
                                                                                                                                                                                  * no part of this software, including this file, may be copied, modified,
                                                                                                                                                                                  * propagated, or distributed except according to the terms contained in the
                                                                                                                                                                                  * LICENSE file.
                                                                                                                                                                                  *
                                                                                                                                                                                  * Removal or modification of this copyright notice is prohibited.
                                                                                                                                                                                  *
                                                                                                                                                                                  */
const decryptMessage = exports.decryptMessage = ({
	cipher,
	nonce,
	passphrase,
	senderPublicKey
}) => ({
	message: _liskElements.cryptography.decryptMessageWithPassphrase(cipher, nonce, passphrase, senderPublicKey)
});

const encryptPassphrase = exports.encryptPassphrase = ({ passphrase, password }) => {
	const encryptedPassphraseObject = _liskElements.cryptography.encryptPassphraseWithPassword(passphrase, password);
	const encryptedPassphrase = _liskElements.cryptography.stringifyEncryptedPassphrase(encryptedPassphraseObject);
	return { encryptedPassphrase };
};

const decryptPassphrase = exports.decryptPassphrase = ({ encryptedPassphrase, password }) => {
	const encryptedPassphraseObject = _liskElements.cryptography.parseEncryptedPassphrase(encryptedPassphrase);
	const passphrase = _liskElements.cryptography.decryptPassphraseWithPassword(encryptedPassphraseObject, password);
	return { passphrase };
};

const { getKeys } = _liskElements.cryptography;

exports.getKeys = getKeys;
const getAddressFromPublicKey = exports.getAddressFromPublicKey = publicKey => ({
	address: _liskElements.cryptography.getAddressFromPublicKey(publicKey)
});

const signMessage = exports.signMessage = ({ message, passphrase }) => _liskElements.cryptography.signMessageWithPassphrase(message, passphrase);

const verifyMessage = exports.verifyMessage = ({ publicKey, signature, message }) => ({
	verified: _liskElements.cryptography.verifyMessageWithPublicKey({
		publicKey,
		signature,
		message
	})
});